#ifndef POKEPLATINUM_UNK_0205E7D0_H
#define POKEPLATINUM_UNK_0205E7D0_H

#include "struct_decls/struct_0203CDB0_decl.h"
#include "struct_decls/struct_0205E884_decl.h"
#include "struct_defs/struct_0205EC34.h"
#include "struct_decls/struct_02061830_decl.h"
#include "struct_decls/struct_02061AB4_decl.h"
#include "overlay101/struct_ov101_021D5D90_decl.h"

#include <nitro/fx/fx.h>

UnkStruct_0205E884 * sub_0205E7D0(const UnkStruct_02061830 * param0, int param1, int param2, int param3, int param4, int param5, int param6, UnkStruct_0205EC34 * param7);
UnkStruct_0205E884 * sub_0205E820(const UnkStruct_02061830 * param0, UnkStruct_0205EC34 * param1, int param2);
void sub_0205E884(UnkStruct_0205E884 * param0, int param1);
void sub_0205E8E0(UnkStruct_0205E884 * param0);
void sub_0205E8E8(UnkStruct_0205E884 * param0);
UnkStruct_02061AB4 * sub_0205EA24(const UnkStruct_02061830 * param0);
int sub_0205EA78(UnkStruct_0205E884 * const param0);
void sub_0205EA84(UnkStruct_0205E884 * param0, int param1);
int sub_0205EA94(UnkStruct_0205E884 * const param0);
int sub_0205EAA0(UnkStruct_0205E884 * const param0);
int sub_0205EABC(UnkStruct_0205E884 * const param0);
int sub_0205EAC8(UnkStruct_0205E884 * const param0);
int sub_0205EAD4(UnkStruct_0205E884 * const param0);
int sub_0205EAE0(UnkStruct_0205E884 * const param0);
void sub_0205EAEC(UnkStruct_0205E884 * const param0, VecFx32 * param1);
const VecFx32 * sub_0205EAFC(UnkStruct_0205E884 * const param0);
void sub_0205EB08(UnkStruct_0205E884 * param0, int param1);
int sub_0205EB0C(const UnkStruct_0205E884 * param0);
void sub_0205EB10(UnkStruct_0205E884 * param0, int param1);
int sub_0205EB14(const UnkStruct_0205E884 * param0);
void sub_0205EB18(UnkStruct_0205E884 * param0, int param1);
void sub_0205EB38(UnkStruct_0205E884 * param0, UnkStruct_02061AB4 * param1);
UnkStruct_02061AB4 * sub_0205EB3C(UnkStruct_0205E884 * param0);
const UnkStruct_02061AB4 * sub_0205EB54(const UnkStruct_0205E884 * param0);
void sub_0205EB58(UnkStruct_0205E884 * param0, int param1);
int sub_0205EB74(UnkStruct_0205E884 * param0);
void sub_0205EB84(UnkStruct_0205E884 * param0, u32 param1);
void sub_0205EB8C(UnkStruct_0205E884 * param0, u32 param1);
u32 sub_0205EB90(UnkStruct_0205E884 * param0);
void sub_0205EB94(UnkStruct_0205E884 * param0, int param1);
int sub_0205EB98(UnkStruct_0205E884 * param0);
int sub_0205EBB8(UnkStruct_0205E884 * param0);
void sub_0205EBBC(UnkStruct_0205E884 * param0, int param1);
void sub_0205EBC0(UnkStruct_0205E884 * param0);
int sub_0205EBCC(UnkStruct_0205E884 * param0, int param1, int param2);
void sub_0205EBDC(UnkStruct_0205E884 * param0, int param1);
int sub_0205EBE0(UnkStruct_0205E884 * param0);
void sub_0205EBE4(UnkStruct_0205E884 * param0, int param1);
int sub_0205EBE8(UnkStruct_0205E884 * param0);
void sub_0205EBEC(UnkStruct_0205E884 * param0, int param1, int param2);
void sub_0205EC00(UnkStruct_0205E884 * param0, UnkStruct_ov101_021D5D90 * param1);
UnkStruct_ov101_021D5D90 * sub_0205EC04(UnkStruct_0205E884 * param0);
UnkStruct_0205EC34 * sub_0205EC0C(UnkStruct_0205E884 * param0);
void sub_0205EC10(UnkStruct_0205E884 * param0, u32 param1);
u32 sub_0205EC14(UnkStruct_0205E884 * param0);
void sub_0205EC18(UnkStruct_0205E884 * param0, int param1);
int sub_0205EC1C(UnkStruct_0205E884 * param0);
void sub_0205EC20(UnkStruct_0205E884 * param0, u32 param1, int param2);
void sub_0205EC34(UnkStruct_0205EC34 * param0);
int sub_0205EC40(UnkStruct_0205EC34 * param0);
void sub_0205EC54(UnkStruct_0205EC34 * param0, int param1);
int sub_0205EC64(UnkStruct_0205EC34 * param0);
void sub_0205EC70(UnkStruct_0205EC34 * param0, int param1);
void sub_0205EC78(UnkStruct_0205E884 * param0, int param1);
int sub_0205EC88(UnkStruct_0205E884 * param0);
u32 sub_0205EC94(UnkStruct_0205EC34 * param0);
void sub_0205ECA0(UnkStruct_0205EC34 * param0, u32 param1);
void sub_0205ECA8(UnkStruct_0205E884 * param0, u32 param1);
void sub_0205ECB8(UnkStruct_0205E884 * param0, const VecFx32 * param1, int param2);
void sub_0205ECE0(UnkStruct_0205E884 * param0, int param1, int param2, int param3);
void sub_0205ED0C(UnkStruct_0205E884 * param0, fx32 param1);
void sub_0205ED2C(UnkStruct_0205E884 * param0, int param1);
void sub_0205ED48(UnkStruct_0205E884 * param0, int param1);
int sub_0205ED6C(int param0, int param1);
u32 sub_0205EED8(int param0);
UnkStruct_0205E884 * sub_0205EF3C(UnkStruct_0203CDB0 * param0);
void sub_0205EF40(UnkStruct_0205E884 * param0, int param1);
int sub_0205EF58(UnkStruct_0205E884 * param0);
void sub_0205EF6C(UnkStruct_0205E884 * param0, int param1);
int sub_0205EF84(UnkStruct_0205E884 * param0);
void sub_0205EF98(UnkStruct_0205E884 * param0, int param1);
int sub_0205EFB0(UnkStruct_0205E884 * param0);
void sub_0205EFC4(UnkStruct_0205E884 * param0, int param1);
int sub_0205EFDC(UnkStruct_0205E884 * param0);
void sub_0205EFF0(UnkStruct_0205E884 * param0, int param1);
int sub_0205F008(UnkStruct_0205E884 * param0);
void sub_0205F01C(UnkStruct_0205E884 * param0, int param1);
int sub_0205F034(UnkStruct_0205E884 * param0);
void sub_0205F048(UnkStruct_0205E884 * param0);
void sub_0205F054(UnkStruct_0205E884 * param0);
int sub_0205F060(UnkStruct_0205E884 * param0);
void sub_0205F074(UnkStruct_0205E884 * param0, int param1);
int sub_0205F08C(UnkStruct_0205E884 * param0);
void sub_0205F098(UnkStruct_0205E884 * param0, int param1);
int sub_0205F108(UnkStruct_0205E884 * const param0);
BOOL sub_0205F158(UnkStruct_0205E884 * const param0);
BOOL sub_0205F16C(UnkStruct_0205E884 * const param0);

#endif // POKEPLATINUM_UNK_0205E7D0_H
